@@ -56,6 +56,8 @@ static GParamSpec *properties[NUM_PROPS] = { NULL, };
 
 G_DEFINE_TYPE (GepubWidget, gepub_widget, WEBKIT_TYPE_WEB_VIEW)
 
+#define HUNDRED_PERCENT 100.0
+
 static void
 scroll_to_chapter_pos (GepubWidget *widget) {
     gchar *script = g_strdup_printf("document.querySelector('body').scrollTo(%d, 0)", widget->chapter_pos);
@@ -107,7 +109,7 @@ pagination_initialize_finished (GObject      *object,
         widget->chapter_length = (int)n;
 
         if (widget->init_chapter_pos) {
-            widget->chapter_pos = widget->init_chapter_pos * widget->chapter_length / 100;
+            widget->chapter_pos = widget->init_chapter_pos * widget->chapter_length / HUNDRED_PERCENT;
             if (widget->chapter_pos > (widget->chapter_length - widget->length)) {
                 widget->chapter_pos = (widget->chapter_length - widget->length);
             }
@@ -192,9 +194,15 @@ reload_length_cb (GtkWidget *widget,
     }
 
     if (l) {
+        char line_height[G_ASCII_DTOSTR_BUF_SIZE];
+
+        g_ascii_formatd (line_height,
+                         G_ASCII_DTOSTR_BUF_SIZE,
+                         "%f",
+                         l);
         script = g_strdup_printf (
-            "document.querySelector('#gepubwrap').style.lineHeight = %f;"
-            , l);
+            "document.querySelector('#gepubwrap').style.lineHeight = %s;"
+            , line_height);
         webkit_web_view_run_javascript (web_view, script, NULL, NULL, NULL);
         g_free (script);
     }
@@ -335,9 +343,6 @@ gepub_widget_init (GepubWidget *widget)
     widget->margin = 20;
     widget->font_size = 0;
     widget->line_height = 0;
-
-    // locale to avoid '1,2' in line_height string composition
-    setlocale(LC_NUMERIC, "C");
 }
 
 static void
@@ -396,8 +401,8 @@ gepub_widget_class_init (GepubWidgetClass *klass)
     properties[PROP_CHAPTER_POS] =
         g_param_spec_float ("chapter_pos",
                             "Current position in chapter",
-                            "Current position in chapter",
-                            0, 100, 0,
+                            "Current position in chapter as a percentage",
+                            0.0, HUNDRED_PERCENT, 0.0,
                             G_PARAM_READWRITE);
 
     g_object_class_install_properties (object_class, NUM_PROPS, properties);
@@ -627,7 +632,7 @@ gepub_widget_page_prev (GepubWidget *widget)
     widget->chapter_pos = widget->chapter_pos - widget->length;
 
     if (widget->chapter_pos < 0) {
-        widget->init_chapter_pos = 100;
+        widget->init_chapter_pos = HUNDRED_PERCENT;
         return gepub_doc_go_prev (widget->doc);
     }
 
@@ -652,7 +657,7 @@ gepub_widget_get_pos (GepubWidget *widget)
         return 0;
     }
 
-    return widget->chapter_pos * 100 / (float)(widget->chapter_length);
+    return widget->chapter_pos * HUNDRED_PERCENT / (float)(widget->chapter_length);
 }
 
 /**
@@ -667,7 +672,7 @@ gepub_widget_set_pos (GepubWidget *widget,
                       gfloat       index)
 {
     g_return_if_fail (GEPUB_IS_DOC (widget->doc));
-    widget->chapter_pos = index * widget->chapter_length / 100;
+    widget->chapter_pos = index * widget->chapter_length / HUNDRED_PERCENT;
     adjust_chapter_pos (widget);
 
     g_object_notify_by_pspec (G_OBJECT (widget), properties[PROP_CHAPTER_POS]);
